@@ -43,6 +43,9 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         );
     }
 
+    /**
+     * @group legacy
+     */
     public function testConstructorWithoutDateType()
     {
         $formatter = $this->getDateFormatter('en', null, IntlDateFormatter::SHORT, 'UTC', IntlDateFormatter::GREGORIAN);
@@ -50,6 +53,9 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         $this->assertSame('EEEE, MMMM d, y \'at\' h:mm a', $formatter->getPattern());
     }
 
+    /**
+     * @group legacy
+     */
     public function testConstructorWithoutTimeType()
     {
         $formatter = $this->getDateFormatter('en', IntlDateFormatter::SHORT, null, 'UTC', IntlDateFormatter::GREGORIAN);
@@ -479,6 +485,16 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         date_default_timezone_set($tz);
     }
 
+    public function testFormatIgnoresPatternForRelativeDateType()
+    {
+        $formatter = $this->getDateFormatter('en', IntlDateFormatter::RELATIVE_FULL, IntlDateFormatter::FULL, new \DateTimeZone('GMT'), IntlDateFormatter::GREGORIAN, 'zzzz');
+
+        $datetime = \DateTime::createFromFormat('U', time(), new \DateTimeZone('GMT'));
+        $datetime->setTime(0, 0, 0);
+
+        $this->assertSame('today at 12:00:00 AM Greenwich Mean Time', $formatter->format($datetime));
+    }
+
     /**
      * @dataProvider dateAndTimeTypeProvider
      */
@@ -502,6 +518,43 @@ abstract class AbstractIntlDateFormatterTest extends TestCase
         ];
     }
 
+    /**
+     * @dataProvider relativeDateTypeProvider
+     */
+    public function testRelativeDateType($timestamp, $datetype, $timetype, $expected)
+    {
+        $datetime = \DateTime::createFromFormat('U', $timestamp, new \DateTimeZone('UTC'));
+        $datetime->setTime(0, 0, 0);
+
+        $formatter = $this->getDateFormatter('en', $datetype, $timetype, 'UTC');
+        $this->assertSame($expected, $formatter->format($datetime));
+    }
+
+    public function relativeDateTypeProvider()
+    {
+        return [
+            [0, IntlDateFormatter::RELATIVE_FULL, IntlDateFormatter::NONE, 'Thursday, January 1, 1970'],
+            [0, IntlDateFormatter::RELATIVE_LONG, IntlDateFormatter::NONE, 'January 1, 1970'],
+            [0, IntlDateFormatter::RELATIVE_MEDIUM, IntlDateFormatter::NONE, 'Jan 1, 1970'],
+            [0, IntlDateFormatter::RELATIVE_SHORT, IntlDateFormatter::NONE, '1/1/70'],
+
+            [time(), IntlDateFormatter::RELATIVE_FULL, IntlDateFormatter::NONE, 'today'],
+            [time(), IntlDateFormatter::RELATIVE_LONG, IntlDateFormatter::FULL, 'today at 12:00:00 AM Coordinated Universal Time'],
+            [time(), IntlDateFormatter::RELATIVE_MEDIUM, IntlDateFormatter::LONG, 'today, 12:00:00 AM UTC'],
+            [time(), IntlDateFormatter::RELATIVE_SHORT, IntlDateFormatter::SHORT, 'today, 12:00 AM'],
+
+            [strtotime('-1 day', time()), IntlDateFormatter::RELATIVE_FULL, IntlDateFormatter::NONE, 'yesterday'],
+            [strtotime('-1 day', time()), IntlDateFormatter::RELATIVE_LONG, IntlDateFormatter::FULL, 'yesterday at 12:00:00 AM Coordinated Universal Time'],
+            [strtotime('-1 day', time()), IntlDateFormatter::RELATIVE_MEDIUM, IntlDateFormatter::LONG, 'yesterday, 12:00:00 AM UTC'],
+            [strtotime('-1 day', time()), IntlDateFormatter::RELATIVE_SHORT, IntlDateFormatter::SHORT, 'yesterday, 12:00 AM'],
+
+            [strtotime('+1 day', time()), IntlDateFormatter::RELATIVE_FULL, IntlDateFormatter::NONE, 'tomorrow'],
+            [strtotime('+1 day', time()), IntlDateFormatter::RELATIVE_LONG, IntlDateFormatter::FULL, 'tomorrow at 12:00:00 AM Coordinated Universal Time'],
+            [strtotime('+1 day', time()), IntlDateFormatter::RELATIVE_MEDIUM, IntlDateFormatter::LONG, 'tomorrow, 12:00:00 AM UTC'],
+            [strtotime('+1 day', time()), IntlDateFormatter::RELATIVE_SHORT, IntlDateFormatter::SHORT, 'tomorrow, 12:00 AM'],
+        ];
+    }
+
     public function testGetCalendar()
     {
         $formatter = $this->getDefaultDateFormatter();
