@@ -254,14 +254,16 @@ class MbstringTest extends TestCase
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_strtolower
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_strtoupper
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_convert_case
+     *
+     * @requires PHP 7.3
      */
     public function testStrCase()
     {
-        $this->assertSame(\PHP_VERSION_ID >= 70300 ? 'i̇' : 'i', mb_strtolower('İ'));
-        $this->assertSame('déjà σσς iiıi', p::mb_strtolower('DÉJÀ Σσς İIıi'));
+        $this->assertSame('i̇', mb_strtolower('İ'));
+        $this->assertSame('déjà σσς i̇iıi', p::mb_strtolower('DÉJÀ Σσς İIıi'));
         $this->assertSame('DÉJÀ ΣΣΣ İIII', mb_strtoupper('Déjà Σσς İIıi'));
         if (\PCRE_VERSION >= '8.10') {
-            $this->assertSame('Déjà Σσσ Iı Ii İi', p::mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', \MB_CASE_TITLE));
+            $this->assertSame('Déjà Σσσ Iı Ii İi̇', p::mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', \MB_CASE_TITLE));
         }
         $this->assertSame('ab', str_replace('?', '', mb_strtolower(urldecode('a%A1%C0b'))));
     }
@@ -438,7 +440,6 @@ class MbstringTest extends TestCase
         $this->assertSame('ÉJÀDÉJÀ', mb_stristr('DÉJÀDÉJÀ', 'é'));
         $this->assertSame('ςσb', mb_stristr('aςσb', 'ΣΣ'));
         $this->assertSame('éjà', mb_strrchr('déjàdéjà', 'é'));
-        $this->assertSame('éjà', mb_strrchr('déjàdéjà', 'é', false, 'ASCII'));
         $this->assertFalse(mb_strrchr('déjàdéjà', 'X', false, 'ASCII'));
         $this->assertSame('ÉJÀ', mb_strrichr('DÉJÀDÉJÀ', 'é'));
 
@@ -446,10 +447,12 @@ class MbstringTest extends TestCase
         $this->assertSame('D', mb_stristr('DÉJÀDÉJÀ', 'é', true));
         $this->assertSame('a', mb_stristr('aςσb', 'ΣΣ', true));
         $this->assertSame('déjàd', mb_strrchr('déjàdéjà', 'é', true));
-        $this->assertSame('déjàd', mb_strrchr('déjàdéjà', 'é', true, 'ASCII'));
         $this->assertFalse(mb_strrchr('déjàdéjà', 'X', true, 'ASCII'));
         $this->assertSame('DÉJÀD', mb_strrichr('DÉJÀDÉJÀ', 'é', true));
         $this->assertSame('Paris', mb_stristr('der Straße nach Paris', 'Paris'));
+
+        $this->assertSame('éjà', mb_strrchr('déjàdéjà', 'é', false, '8BIT'));
+        $this->assertSame('déjàd', mb_strrchr('déjàdéjà', 'é', true, '8BIT'));
     }
 
     /**
@@ -472,7 +475,7 @@ class MbstringTest extends TestCase
         $this->assertSame('ASCII', mb_detect_encoding('abc'));
         $this->assertSame('UTF-8', mb_detect_encoding('abc', 'UTF8, ASCII'));
         $this->assertSame('ISO-8859-1', mb_detect_encoding("\xE9", ['UTF-8', 'ASCII', 'ISO-8859-1'], true));
-        $this->assertFalse(mb_detect_encoding("\xE9", ['UTF-8', 'ASCII', 'Windows-1252'], true));
+        $this->assertFalse(mb_detect_encoding("\xE9", ['UTF-8', 'ASCII'], true));
     }
 
     /**
@@ -552,4 +555,28 @@ class MbstringTest extends TestCase
         $this->assertSame('ab', mb_scrub("a\xE9b"));
         mb_substitute_character($subst);
     }
+
+    /**
+     * @group legacy
+     */
+    public function testParseStr()
+    {
+        $result = [];
+        static::assertTrue(mb_parse_str('test1=&test2=value', $result));
+        static::assertTrue(mb_parse_str(0, $result));
+        static::assertFalse(mb_parse_str('', $result));
+        static::assertFalse(mb_parse_str(null, $result));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_decode_mimeheader
+     */
+    public function testDecodeMimeheader()
+    {
+        $this->assertTrue(mb_internal_encoding('utf8'));
+        $this->assertSame(sprintf('Test: %s', 'проверка'), mb_decode_mimeheader('Test: =?windows-1251?B?7/Du4uXw6uA=?='));
+        $this->assertTrue(mb_internal_encoding('windows-1251'));
+        $this->assertSame(sprintf('Test: %s', base64_decode('7/Du4uXw6uA=')), mb_decode_mimeheader('Test: =?windows-1251?B?7/Du4uXw6uA=?='));
+        $this->assertTrue(mb_internal_encoding('utf8'));
+    }
 }
