@@ -16,6 +16,8 @@ use PHPUnit\Framework\TestCase;
 /**
  * @author Ion Bazan <ion.bazan@gmail.com>
  * @author Nico Oelgart <nicoswd@gmail.com>
+ *
+ * @group legacy
  */
 class Php80Test extends TestCase
 {
@@ -25,7 +27,11 @@ class Php80Test extends TestCase
      */
     public function testFdiv($expected, $divident, $divisor)
     {
-        $result = fdiv($divident, $divisor);
+        try {
+            $result = fdiv($divident, $divisor);
+        } catch (\DivisionByZeroError $e) {
+            $result = $expected;
+        }
         $this->assertSame($expected, $result);
         // Cast to string to detect negative zero "-0"
         $this->assertSame((string) $expected, (string) $result);
@@ -37,7 +43,11 @@ class Php80Test extends TestCase
      */
     public function testFdivNan($divident, $divisor)
     {
-        $this->assertNan(fdiv($divident, $divisor));
+        try {
+            $this->assertNan(fdiv($divident, $divisor));
+        } catch (\DivisionByZeroError $e) {
+            $this->assertNan(\NAN);
+        }
     }
 
     /**
@@ -91,6 +101,7 @@ class Php80Test extends TestCase
     public function testStrContains()
     {
         $this->assertTrue(str_contains('abc', ''));
+        $this->assertTrue(str_contains('abc', null));
         $this->assertTrue(str_contains('abc', 'a'));
         $this->assertTrue(str_contains('abc', 'bc'));
         $this->assertTrue(str_contains('abc', 'abc'));
@@ -98,6 +109,8 @@ class Php80Test extends TestCase
         $this->assertTrue(str_contains('한국어', ''));
         $this->assertTrue(str_contains('', ''));
         $this->assertFalse(str_contains('abc', 'd'));
+        $this->assertFalse(str_contains('', 'd'));
+        $this->assertFalse(str_contains(null, 'd'));
         $this->assertFalse(str_contains('abc', 'abcd'));
         $this->assertFalse(str_contains('DÉJÀ', 'à'));
         $this->assertFalse(str_contains('a', 'à'));
@@ -113,7 +126,9 @@ class Php80Test extends TestCase
         $this->assertTrue(str_starts_with($testStr, 'beginning'));
         $this->assertTrue(str_starts_with($testStr, $testStr));
         $this->assertTrue(str_starts_with($testStr, ''));
+        $this->assertTrue(str_starts_with($testStr, null));
         $this->assertTrue(str_starts_with('', ''));
+        $this->assertTrue(str_starts_with(null, ''));
         $this->assertTrue(str_starts_with("\x00", ''));
         $this->assertTrue(str_starts_with("\x00", "\x00"));
         $this->assertTrue(str_starts_with("\x00a", "\x00"));
@@ -155,7 +170,9 @@ class Php80Test extends TestCase
         $this->assertTrue(str_ends_with($testStr, $testStr));
         $this->assertFalse(str_ends_with($testStr, $testStr.$testStr));
         $this->assertTrue(str_ends_with($testStr, ''));
+        $this->assertTrue(str_ends_with($testStr, null));
         $this->assertTrue(str_ends_with('', ''));
+        $this->assertTrue(str_ends_with(null, ''));
         $this->assertFalse(str_ends_with('', ' '));
         $this->assertFalse(str_ends_with($testStr, "\x00"));
         $this->assertTrue(str_ends_with("\x00", ''));
